==> knative-model-6.1.0-sources.jar: io/fabric8/knative/flows/v1/ParallelStatusFluent.java <==
package io.fabric8.knative.flows.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.internal.pkg.apis.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.duck.v1.AddressableFluent;
import java.lang.Integer;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import java.lang.Long;
import io.fabric8.knative.internal.pkg.apis.duck.v1.Addressable;
import java.util.Collection;
import java.util.Map;

 /**
  * Generated
  */
public interface ParallelStatusFluent<A extends ParallelStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAddress instead.
   * @return The buildable object.
   */
  @Deprecated
  public Addressable getAddress();
  public Addressable buildAddress();
  public A withAddress(Addressable address);
  public Boolean hasAddress();
  public A withNewAddress(String url);
  public ParallelStatusFluent.AddressNested<A> withNewAddress();
  public ParallelStatusFluent.AddressNested<A> withNewAddressLike(Addressable item);
  public ParallelStatusFluent.AddressNested<A> editAddress();
  public ParallelStatusFluent.AddressNested<A> editOrNewAddress();
  public ParallelStatusFluent.AddressNested<A> editOrNewAddressLike(Addressable item);
  public A addToAnnotations(String key,String value);
  public A addToAnnotations(Map<String,String> map);
  public A removeFromAnnotations(String key);
  public A removeFromAnnotations(Map<String,String> map);
  public Map<String,String> getAnnotations();
  public <K,V>A withAnnotations(Map<String,String> annotations);
  public Boolean hasAnnotations();
  public A addToBranchStatuses(Integer index,ParallelBranchStatus item);
  public A setToBranchStatuses(Integer index,ParallelBranchStatus item);
  public A addToBranchStatuses(io.fabric8.knative.flows.v1.ParallelBranchStatus... items);
  public A addAllToBranchStatuses(Collection<ParallelBranchStatus> items);
  public A removeFromBranchStatuses(io.fabric8.knative.flows.v1.ParallelBranchStatus... items);
  public A removeAllFromBranchStatuses(Collection<ParallelBranchStatus> items);
  public A removeMatchingFromBranchStatuses(Predicate<ParallelBranchStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildBranchStatuses instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ParallelBranchStatus> getBranchStatuses();
  public List<ParallelBranchStatus> buildBranchStatuses();
  public ParallelBranchStatus buildBranchStatus(Integer index);
  public ParallelBranchStatus buildFirstBranchStatus();
  public ParallelBranchStatus buildLastBranchStatus();
  public ParallelBranchStatus buildMatchingBranchStatus(Predicate<ParallelBranchStatusBuilder> predicate);
  public Boolean hasMatchingBranchStatus(Predicate<ParallelBranchStatusBuilder> predicate);
  public A withBranchStatuses(List<ParallelBranchStatus> branchStatuses);
  public A withBranchStatuses(io.fabric8.knative.flows.v1.ParallelBranchStatus... branchStatuses);
  public Boolean hasBranchStatuses();
  public ParallelStatusFluent.BranchStatusesNested<A> addNewBranchStatus();
  public ParallelStatusFluent.BranchStatusesNested<A> addNewBranchStatusLike(ParallelBranchStatus item);
  public ParallelStatusFluent.BranchStatusesNested<A> setNewBranchStatusLike(Integer index,ParallelBranchStatus item);
  public ParallelStatusFluent.BranchStatusesNested<A> editBranchStatus(Integer index);
  public ParallelStatusFluent.BranchStatusesNested<A> editFirstBranchStatus();
  public ParallelStatusFluent.BranchStatusesNested<A> editLastBranchStatus();
  public ParallelStatusFluent.BranchStatusesNested<A> editMatchingBranchStatus(Predicate<ParallelBranchStatusBuilder> predicate);
  public A addToConditions(Integer index,Condition item);
  public A setToConditions(Integer index,Condition item);
  public A addToConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A addAllToConditions(Collection<Condition> items);
  public A removeFromConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A removeAllFromConditions(Collection<Condition> items);
  public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Condition> getConditions();
  public List<Condition> buildConditions();
  public Condition buildCondition(Integer index);
  public Condition buildFirstCondition();
  public Condition buildLastCondition();
  public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
  public A withConditions(List<Condition> conditions);
  public A withConditions(io.fabric8.knative.internal.pkg.apis.Condition... conditions);
  public Boolean hasConditions();
  public ParallelStatusFluent.ConditionsNested<A> addNewCondition();
  public ParallelStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
  public ParallelStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,Condition item);
  public ParallelStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public ParallelStatusFluent.ConditionsNested<A> editFirstCondition();
  public ParallelStatusFluent.ConditionsNested<A> editLastCondition();
  public ParallelStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildIngressChannelStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public ParallelChannelStatus getIngressChannelStatus();
  public ParallelChannelStatus buildIngressChannelStatus();
  public A withIngressChannelStatus(ParallelChannelStatus ingressChannelStatus);
  public Boolean hasIngressChannelStatus();
  public ParallelStatusFluent.IngressChannelStatusNested<A> withNewIngressChannelStatus();
  public ParallelStatusFluent.IngressChannelStatusNested<A> withNewIngressChannelStatusLike(ParallelChannelStatus item);
  public ParallelStatusFluent.IngressChannelStatusNested<A> editIngressChannelStatus();
  public ParallelStatusFluent.IngressChannelStatusNested<A> editOrNewIngressChannelStatus();
  public ParallelStatusFluent.IngressChannelStatusNested<A> editOrNewIngressChannelStatusLike(ParallelChannelStatus item);
  public Long getObservedGeneration();
  public A withObservedGeneration(Long observedGeneration);
  public Boolean hasObservedGeneration();
  public interface AddressNested<N> extends Nested<N>,AddressableFluent<ParallelStatusFluent.AddressNested<N>>{
    public N and();
    public N endAddress();
    
  }
  public interface BranchStatusesNested<N> extends Nested<N>,ParallelBranchStatusFluent<ParallelStatusFluent.BranchStatusesNested<N>>{
    public N and();
    public N endBranchStatus();
    
  }
  public interface ConditionsNested<N> extends Nested<N>,ConditionFluent<ParallelStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface IngressChannelStatusNested<N> extends Nested<N>,ParallelChannelStatusFluent<ParallelStatusFluent.IngressChannelStatusNested<N>>{
    public N and();
    public N endIngressChannelStatus();
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/flows/v1/ParallelStatusFluent.java <==
package io.fabric8.knative.flows.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.knative.internal.pkg.apis.Condition;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import io.fabric8.knative.internal.pkg.apis.duck.v1.AddressableFluent;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import java.lang.Long;
import io.fabric8.knative.internal.pkg.apis.duck.v1.Addressable;
import java.util.Collection;
import java.util.Map;

 /**
  * Generated
  */
public interface ParallelStatusFluent<A extends ParallelStatusFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildAddress instead.
   * @return The buildable object.
   */
  @Deprecated
  public Addressable getAddress();
  public Addressable buildAddress();
  public A withAddress(Addressable address);
  public Boolean hasAddress();
  public A withNewAddress(String url);
  public ParallelStatusFluent.AddressNested<A> withNewAddress();
  public ParallelStatusFluent.AddressNested<A> withNewAddressLike(Addressable item);
  public ParallelStatusFluent.AddressNested<A> editAddress();
  public ParallelStatusFluent.AddressNested<A> editOrNewAddress();
  public ParallelStatusFluent.AddressNested<A> editOrNewAddressLike(Addressable item);
  public A addToAnnotations(String key,String value);
  public A addToAnnotations(Map<String,String> map);
  public A removeFromAnnotations(String key);
  public A removeFromAnnotations(Map<String,String> map);
  public Map<String,String> getAnnotations();
  public <K,V>A withAnnotations(Map<String,String> annotations);
  public Boolean hasAnnotations();
  public A addToBranchStatuses(int index,ParallelBranchStatus item);
  public A setToBranchStatuses(int index,ParallelBranchStatus item);
  public A addToBranchStatuses(io.fabric8.knative.flows.v1.ParallelBranchStatus... items);
  public A addAllToBranchStatuses(Collection<ParallelBranchStatus> items);
  public A removeFromBranchStatuses(io.fabric8.knative.flows.v1.ParallelBranchStatus... items);
  public A removeAllFromBranchStatuses(Collection<ParallelBranchStatus> items);
  public A removeMatchingFromBranchStatuses(Predicate<ParallelBranchStatusBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildBranchStatuses instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ParallelBranchStatus> getBranchStatuses();
  public List<ParallelBranchStatus> buildBranchStatuses();
  public ParallelBranchStatus buildBranchStatus(int index);
  public ParallelBranchStatus buildFirstBranchStatus();
  public ParallelBranchStatus buildLastBranchStatus();
  public ParallelBranchStatus buildMatchingBranchStatus(Predicate<ParallelBranchStatusBuilder> predicate);
  public Boolean hasMatchingBranchStatus(Predicate<ParallelBranchStatusBuilder> predicate);
  public A withBranchStatuses(List<ParallelBranchStatus> branchStatuses);
  public A withBranchStatuses(io.fabric8.knative.flows.v1.ParallelBranchStatus... branchStatuses);
  public Boolean hasBranchStatuses();
  public ParallelStatusFluent.BranchStatusesNested<A> addNewBranchStatus();
  public ParallelStatusFluent.BranchStatusesNested<A> addNewBranchStatusLike(ParallelBranchStatus item);
  public ParallelStatusFluent.BranchStatusesNested<A> setNewBranchStatusLike(int index,ParallelBranchStatus item);
  public ParallelStatusFluent.BranchStatusesNested<A> editBranchStatus(int index);
  public ParallelStatusFluent.BranchStatusesNested<A> editFirstBranchStatus();
  public ParallelStatusFluent.BranchStatusesNested<A> editLastBranchStatus();
  public ParallelStatusFluent.BranchStatusesNested<A> editMatchingBranchStatus(Predicate<ParallelBranchStatusBuilder> predicate);
  public A addToConditions(int index,Condition item);
  public A setToConditions(int index,Condition item);
  public A addToConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A addAllToConditions(Collection<Condition> items);
  public A removeFromConditions(io.fabric8.knative.internal.pkg.apis.Condition... items);
  public A removeAllFromConditions(Collection<Condition> items);
  public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Condition> getConditions();
  public List<Condition> buildConditions();
  public Condition buildCondition(int index);
  public Condition buildFirstCondition();
  public Condition buildLastCondition();
  public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
  public A withConditions(List<Condition> conditions);
  public A withConditions(io.fabric8.knative.internal.pkg.apis.Condition... conditions);
  public Boolean hasConditions();
  public ParallelStatusFluent.ConditionsNested<A> addNewCondition();
  public ParallelStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
  public ParallelStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
  public ParallelStatusFluent.ConditionsNested<A> editCondition(int index);
  public ParallelStatusFluent.ConditionsNested<A> editFirstCondition();
  public ParallelStatusFluent.ConditionsNested<A> editLastCondition();
  public ParallelStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildIngressChannelStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public ParallelChannelStatus getIngressChannelStatus();
  public ParallelChannelStatus buildIngressChannelStatus();
  public A withIngressChannelStatus(ParallelChannelStatus ingressChannelStatus);
  public Boolean hasIngressChannelStatus();
  public ParallelStatusFluent.IngressChannelStatusNested<A> withNewIngressChannelStatus();
  public ParallelStatusFluent.IngressChannelStatusNested<A> withNewIngressChannelStatusLike(ParallelChannelStatus item);
  public ParallelStatusFluent.IngressChannelStatusNested<A> editIngressChannelStatus();
  public ParallelStatusFluent.IngressChannelStatusNested<A> editOrNewIngressChannelStatus();
  public ParallelStatusFluent.IngressChannelStatusNested<A> editOrNewIngressChannelStatusLike(ParallelChannelStatus item);
  public Long getObservedGeneration();
  public A withObservedGeneration(Long observedGeneration);
  public Boolean hasObservedGeneration();
  public interface AddressNested<N> extends Nested<N>,AddressableFluent<ParallelStatusFluent.AddressNested<N>>{
    public N and();
    public N endAddress();
    
  }
  public interface BranchStatusesNested<N> extends Nested<N>,ParallelBranchStatusFluent<ParallelStatusFluent.BranchStatusesNested<N>>{
    public N and();
    public N endBranchStatus();
    
  }
  public interface ConditionsNested<N> extends Nested<N>,ConditionFluent<ParallelStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface IngressChannelStatusNested<N> extends Nested<N>,ParallelChannelStatusFluent<ParallelStatusFluent.IngressChannelStatusNested<N>>{
    public N and();
    public N endIngressChannelStatus();
    
  }
  
}
